The Git module
==============

The git module is designed to allow interaction between the bot and git repositories which are used to store run configurations and results.

The git module contains two major classes for dealing with individual repositories and "metarepositories", or collections of repositories.

.. automodule:: asimov.git
   :members:
   :undoc-members:
   :show-inheritance:
